# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v2alpha/http.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.data.tap.v2alpha import common_pb2 as envoy_dot_data_dot_tap_dot_v2alpha_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/data/tap/v2alpha/http.proto',
  package='envoy.data.tap.v2alpha',
  syntax='proto3',
  serialized_options=b'\n$io.envoyproxy.envoy.data.tap.v2alphaB\tHttpProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!envoy/data/tap/v2alpha/http.proto\x12\x16\x65nvoy.data.tap.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a#envoy/data/tap/v2alpha/common.proto\x1a\x1dudpa/annotations/status.proto\"\xb7\x02\n\x11HttpBufferedTrace\x12\x42\n\x07request\x18\x01 \x01(\x0b\x32\x31.envoy.data.tap.v2alpha.HttpBufferedTrace.Message\x12\x43\n\x08response\x18\x02 \x01(\x0b\x32\x31.envoy.data.tap.v2alpha.HttpBufferedTrace.Message\x1a\x98\x01\n\x07Message\x12/\n\x07headers\x18\x01 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\x12*\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x1c.envoy.data.tap.v2alpha.Body\x12\x30\n\x08trailers\x18\x03 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\"\x9e\x03\n\x18HttpStreamedTraceSegment\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x37\n\x0frequest_headers\x18\x02 \x01(\x0b\x32\x1c.envoy.api.v2.core.HeaderMapH\x00\x12:\n\x12request_body_chunk\x18\x03 \x01(\x0b\x32\x1c.envoy.data.tap.v2alpha.BodyH\x00\x12\x38\n\x10request_trailers\x18\x04 \x01(\x0b\x32\x1c.envoy.api.v2.core.HeaderMapH\x00\x12\x38\n\x10response_headers\x18\x05 \x01(\x0b\x32\x1c.envoy.api.v2.core.HeaderMapH\x00\x12;\n\x13response_body_chunk\x18\x06 \x01(\x0b\x32\x1c.envoy.data.tap.v2alpha.BodyH\x00\x12\x39\n\x11response_trailers\x18\x07 \x01(\x0b\x32\x1c.envoy.api.v2.core.HeaderMapH\x00\x42\x0f\n\rmessage_pieceB;\n$io.envoyproxy.envoy.data.tap.v2alphaB\tHttpProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_data_dot_tap_dot_v2alpha_dot_common__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_HTTPBUFFEREDTRACE_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='envoy.data.tap.v2alpha.HttpBufferedTrace.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.data.tap.v2alpha.HttpBufferedTrace.Message.headers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='envoy.data.tap.v2alpha.HttpBufferedTrace.Message.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trailers', full_name='envoy.data.tap.v2alpha.HttpBufferedTrace.Message.trailers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=471,
)

_HTTPBUFFEREDTRACE = _descriptor.Descriptor(
  name='HttpBufferedTrace',
  full_name='envoy.data.tap.v2alpha.HttpBufferedTrace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='envoy.data.tap.v2alpha.HttpBufferedTrace.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='envoy.data.tap.v2alpha.HttpBufferedTrace.response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTPBUFFEREDTRACE_MESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=471,
)


_HTTPSTREAMEDTRACESEGMENT = _descriptor.Descriptor(
  name='HttpStreamedTraceSegment',
  full_name='envoy.data.tap.v2alpha.HttpStreamedTraceSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='envoy.data.tap.v2alpha.HttpStreamedTraceSegment.trace_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers', full_name='envoy.data.tap.v2alpha.HttpStreamedTraceSegment.request_headers', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_body_chunk', full_name='envoy.data.tap.v2alpha.HttpStreamedTraceSegment.request_body_chunk', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_trailers', full_name='envoy.data.tap.v2alpha.HttpStreamedTraceSegment.request_trailers', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers', full_name='envoy.data.tap.v2alpha.HttpStreamedTraceSegment.response_headers', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_body_chunk', full_name='envoy.data.tap.v2alpha.HttpStreamedTraceSegment.response_body_chunk', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_trailers', full_name='envoy.data.tap.v2alpha.HttpStreamedTraceSegment.response_trailers', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message_piece', full_name='envoy.data.tap.v2alpha.HttpStreamedTraceSegment.message_piece',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=474,
  serialized_end=888,
)

_HTTPBUFFEREDTRACE_MESSAGE.fields_by_name['headers'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERVALUE
_HTTPBUFFEREDTRACE_MESSAGE.fields_by_name['body'].message_type = envoy_dot_data_dot_tap_dot_v2alpha_dot_common__pb2._BODY
_HTTPBUFFEREDTRACE_MESSAGE.fields_by_name['trailers'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERVALUE
_HTTPBUFFEREDTRACE_MESSAGE.containing_type = _HTTPBUFFEREDTRACE
_HTTPBUFFEREDTRACE.fields_by_name['request'].message_type = _HTTPBUFFEREDTRACE_MESSAGE
_HTTPBUFFEREDTRACE.fields_by_name['response'].message_type = _HTTPBUFFEREDTRACE_MESSAGE
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_headers'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERMAP
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_body_chunk'].message_type = envoy_dot_data_dot_tap_dot_v2alpha_dot_common__pb2._BODY
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_trailers'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERMAP
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_headers'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERMAP
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_body_chunk'].message_type = envoy_dot_data_dot_tap_dot_v2alpha_dot_common__pb2._BODY
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_trailers'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERMAP
_HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_headers'])
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_headers'].containing_oneof = _HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
_HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_body_chunk'])
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_body_chunk'].containing_oneof = _HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
_HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_trailers'])
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['request_trailers'].containing_oneof = _HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
_HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_headers'])
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_headers'].containing_oneof = _HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
_HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_body_chunk'])
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_body_chunk'].containing_oneof = _HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
_HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_trailers'])
_HTTPSTREAMEDTRACESEGMENT.fields_by_name['response_trailers'].containing_oneof = _HTTPSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
DESCRIPTOR.message_types_by_name['HttpBufferedTrace'] = _HTTPBUFFEREDTRACE
DESCRIPTOR.message_types_by_name['HttpStreamedTraceSegment'] = _HTTPSTREAMEDTRACESEGMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpBufferedTrace = _reflection.GeneratedProtocolMessageType('HttpBufferedTrace', (_message.Message,), {

  'Message' : _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
    'DESCRIPTOR' : _HTTPBUFFEREDTRACE_MESSAGE,
    '__module__' : 'envoy.data.tap.v2alpha.http_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.tap.v2alpha.HttpBufferedTrace.Message)
    })
  ,
  'DESCRIPTOR' : _HTTPBUFFEREDTRACE,
  '__module__' : 'envoy.data.tap.v2alpha.http_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v2alpha.HttpBufferedTrace)
  })
_sym_db.RegisterMessage(HttpBufferedTrace)
_sym_db.RegisterMessage(HttpBufferedTrace.Message)

HttpStreamedTraceSegment = _reflection.GeneratedProtocolMessageType('HttpStreamedTraceSegment', (_message.Message,), {
  'DESCRIPTOR' : _HTTPSTREAMEDTRACESEGMENT,
  '__module__' : 'envoy.data.tap.v2alpha.http_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v2alpha.HttpStreamedTraceSegment)
  })
_sym_db.RegisterMessage(HttpStreamedTraceSegment)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v2/hds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import health_check_pb2 as envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2
from envoy.api.v2.endpoint import endpoint_components_pb2 as envoy_dot_api_dot_v2_dot_endpoint_dot_endpoint__components__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/discovery/v2/hds.proto',
  package='envoy.service.discovery.v2',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.discovery.v2B\010HdsProtoP\001\210\001\001\362\230\376\217\005\031\022\027envoy.service.health.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/service/discovery/v2/hds.proto\x12\x1a\x65nvoy.service.discovery.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/health_check.proto\x1a/envoy/api/v2/endpoint/endpoint_components.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x87\x01\n\nCapability\x12O\n\x16health_check_protocols\x18\x01 \x03(\x0e\x32/.envoy.service.discovery.v2.Capability.Protocol\"(\n\x08Protocol\x12\x08\n\x04HTTP\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\t\n\x05REDIS\x10\x02\"w\n\x12HealthCheckRequest\x12%\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.Node\x12:\n\ncapability\x18\x02 \x01(\x0b\x32&.envoy.service.discovery.v2.Capability\"{\n\x0e\x45ndpointHealth\x12\x31\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.endpoint.Endpoint\x12\x36\n\rhealth_status\x18\x02 \x01(\x0e\x32\x1f.envoy.api.v2.core.HealthStatus\"^\n\x16\x45ndpointHealthResponse\x12\x44\n\x10\x65ndpoints_health\x18\x01 \x03(\x0b\x32*.envoy.service.discovery.v2.EndpointHealth\"\xe4\x01\n*HealthCheckRequestOrEndpointHealthResponse\x12N\n\x14health_check_request\x18\x01 \x01(\x0b\x32..envoy.service.discovery.v2.HealthCheckRequestH\x00\x12V\n\x18\x65ndpoint_health_response\x18\x02 \x01(\x0b\x32\x32.envoy.service.discovery.v2.EndpointHealthResponseH\x00\x42\x0e\n\x0crequest_type\"v\n\x11LocalityEndpoints\x12-\n\x08locality\x18\x01 \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\x12\x32\n\tendpoints\x18\x02 \x03(\x0b\x32\x1f.envoy.api.v2.endpoint.Endpoint\"\xac\x01\n\x12\x43lusterHealthCheck\x12\x14\n\x0c\x63luster_name\x18\x01 \x01(\t\x12\x35\n\rhealth_checks\x18\x02 \x03(\x0b\x32\x1e.envoy.api.v2.core.HealthCheck\x12I\n\x12locality_endpoints\x18\x03 \x03(\x0b\x32-.envoy.service.discovery.v2.LocalityEndpoints\"\x92\x01\n\x14HealthCheckSpecifier\x12M\n\x15\x63luster_health_checks\x18\x01 \x03(\x0b\x32..envoy.service.discovery.v2.ClusterHealthCheck\x12+\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xea\x02\n\x16HealthDiscoveryService\x12\x93\x01\n\x11StreamHealthCheck\x12\x46.envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse\x1a\x30.envoy.service.discovery.v2.HealthCheckSpecifier\"\x00(\x01\x30\x01\x12\xb9\x01\n\x10\x46\x65tchHealthCheck\x12\x46.envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse\x1a\x30.envoy.service.discovery.v2.HealthCheckSpecifier\"+\x82\xd3\xe4\x93\x02\x1c\"\x1a/v2/discovery:health_check\x82\xd3\xe4\x93\x02\x03:\x01*B`\n(io.envoyproxy.envoy.service.discovery.v2B\x08HdsProtoP\x01\x88\x01\x01\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.service.health.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_endpoint_dot_endpoint__components__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])



_CAPABILITY_PROTOCOL = _descriptor.EnumDescriptor(
  name='Protocol',
  full_name='envoy.service.discovery.v2.Capability.Protocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HTTP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TCP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REDIS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=406,
  serialized_end=446,
)
_sym_db.RegisterEnumDescriptor(_CAPABILITY_PROTOCOL)


_CAPABILITY = _descriptor.Descriptor(
  name='Capability',
  full_name='envoy.service.discovery.v2.Capability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='health_check_protocols', full_name='envoy.service.discovery.v2.Capability.health_check_protocols', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAPABILITY_PROTOCOL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=446,
)


_HEALTHCHECKREQUEST = _descriptor.Descriptor(
  name='HealthCheckRequest',
  full_name='envoy.service.discovery.v2.HealthCheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.discovery.v2.HealthCheckRequest.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capability', full_name='envoy.service.discovery.v2.HealthCheckRequest.capability', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=567,
)


_ENDPOINTHEALTH = _descriptor.Descriptor(
  name='EndpointHealth',
  full_name='envoy.service.discovery.v2.EndpointHealth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='envoy.service.discovery.v2.EndpointHealth.endpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_status', full_name='envoy.service.discovery.v2.EndpointHealth.health_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=692,
)


_ENDPOINTHEALTHRESPONSE = _descriptor.Descriptor(
  name='EndpointHealthResponse',
  full_name='envoy.service.discovery.v2.EndpointHealthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoints_health', full_name='envoy.service.discovery.v2.EndpointHealthResponse.endpoints_health', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=694,
  serialized_end=788,
)


_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE = _descriptor.Descriptor(
  name='HealthCheckRequestOrEndpointHealthResponse',
  full_name='envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='health_check_request', full_name='envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse.health_check_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint_health_response', full_name='envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse.endpoint_health_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request_type', full_name='envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse.request_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=791,
  serialized_end=1019,
)


_LOCALITYENDPOINTS = _descriptor.Descriptor(
  name='LocalityEndpoints',
  full_name='envoy.service.discovery.v2.LocalityEndpoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locality', full_name='envoy.service.discovery.v2.LocalityEndpoints.locality', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoints', full_name='envoy.service.discovery.v2.LocalityEndpoints.endpoints', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1021,
  serialized_end=1139,
)


_CLUSTERHEALTHCHECK = _descriptor.Descriptor(
  name='ClusterHealthCheck',
  full_name='envoy.service.discovery.v2.ClusterHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='envoy.service.discovery.v2.ClusterHealthCheck.cluster_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_checks', full_name='envoy.service.discovery.v2.ClusterHealthCheck.health_checks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locality_endpoints', full_name='envoy.service.discovery.v2.ClusterHealthCheck.locality_endpoints', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1142,
  serialized_end=1314,
)


_HEALTHCHECKSPECIFIER = _descriptor.Descriptor(
  name='HealthCheckSpecifier',
  full_name='envoy.service.discovery.v2.HealthCheckSpecifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_health_checks', full_name='envoy.service.discovery.v2.HealthCheckSpecifier.cluster_health_checks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='envoy.service.discovery.v2.HealthCheckSpecifier.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1317,
  serialized_end=1463,
)

_CAPABILITY.fields_by_name['health_check_protocols'].enum_type = _CAPABILITY_PROTOCOL
_CAPABILITY_PROTOCOL.containing_type = _CAPABILITY
_HEALTHCHECKREQUEST.fields_by_name['node'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._NODE
_HEALTHCHECKREQUEST.fields_by_name['capability'].message_type = _CAPABILITY
_ENDPOINTHEALTH.fields_by_name['endpoint'].message_type = envoy_dot_api_dot_v2_dot_endpoint_dot_endpoint__components__pb2._ENDPOINT
_ENDPOINTHEALTH.fields_by_name['health_status'].enum_type = envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2._HEALTHSTATUS
_ENDPOINTHEALTHRESPONSE.fields_by_name['endpoints_health'].message_type = _ENDPOINTHEALTH
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['health_check_request'].message_type = _HEALTHCHECKREQUEST
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['endpoint_health_response'].message_type = _ENDPOINTHEALTHRESPONSE
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.oneofs_by_name['request_type'].fields.append(
  _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['health_check_request'])
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['health_check_request'].containing_oneof = _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.oneofs_by_name['request_type']
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.oneofs_by_name['request_type'].fields.append(
  _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['endpoint_health_response'])
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['endpoint_health_response'].containing_oneof = _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.oneofs_by_name['request_type']
_LOCALITYENDPOINTS.fields_by_name['locality'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._LOCALITY
_LOCALITYENDPOINTS.fields_by_name['endpoints'].message_type = envoy_dot_api_dot_v2_dot_endpoint_dot_endpoint__components__pb2._ENDPOINT
_CLUSTERHEALTHCHECK.fields_by_name['health_checks'].message_type = envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2._HEALTHCHECK
_CLUSTERHEALTHCHECK.fields_by_name['locality_endpoints'].message_type = _LOCALITYENDPOINTS
_HEALTHCHECKSPECIFIER.fields_by_name['cluster_health_checks'].message_type = _CLUSTERHEALTHCHECK
_HEALTHCHECKSPECIFIER.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['Capability'] = _CAPABILITY
DESCRIPTOR.message_types_by_name['HealthCheckRequest'] = _HEALTHCHECKREQUEST
DESCRIPTOR.message_types_by_name['EndpointHealth'] = _ENDPOINTHEALTH
DESCRIPTOR.message_types_by_name['EndpointHealthResponse'] = _ENDPOINTHEALTHRESPONSE
DESCRIPTOR.message_types_by_name['HealthCheckRequestOrEndpointHealthResponse'] = _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE
DESCRIPTOR.message_types_by_name['LocalityEndpoints'] = _LOCALITYENDPOINTS
DESCRIPTOR.message_types_by_name['ClusterHealthCheck'] = _CLUSTERHEALTHCHECK
DESCRIPTOR.message_types_by_name['HealthCheckSpecifier'] = _HEALTHCHECKSPECIFIER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Capability = _reflection.GeneratedProtocolMessageType('Capability', (_message.Message,), {
  'DESCRIPTOR' : _CAPABILITY,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.Capability)
  })
_sym_db.RegisterMessage(Capability)

HealthCheckRequest = _reflection.GeneratedProtocolMessageType('HealthCheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKREQUEST,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.HealthCheckRequest)
  })
_sym_db.RegisterMessage(HealthCheckRequest)

EndpointHealth = _reflection.GeneratedProtocolMessageType('EndpointHealth', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTHEALTH,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.EndpointHealth)
  })
_sym_db.RegisterMessage(EndpointHealth)

EndpointHealthResponse = _reflection.GeneratedProtocolMessageType('EndpointHealthResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTHEALTHRESPONSE,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.EndpointHealthResponse)
  })
_sym_db.RegisterMessage(EndpointHealthResponse)

HealthCheckRequestOrEndpointHealthResponse = _reflection.GeneratedProtocolMessageType('HealthCheckRequestOrEndpointHealthResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse)
  })
_sym_db.RegisterMessage(HealthCheckRequestOrEndpointHealthResponse)

LocalityEndpoints = _reflection.GeneratedProtocolMessageType('LocalityEndpoints', (_message.Message,), {
  'DESCRIPTOR' : _LOCALITYENDPOINTS,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.LocalityEndpoints)
  })
_sym_db.RegisterMessage(LocalityEndpoints)

ClusterHealthCheck = _reflection.GeneratedProtocolMessageType('ClusterHealthCheck', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERHEALTHCHECK,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.ClusterHealthCheck)
  })
_sym_db.RegisterMessage(ClusterHealthCheck)

HealthCheckSpecifier = _reflection.GeneratedProtocolMessageType('HealthCheckSpecifier', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKSPECIFIER,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.HealthCheckSpecifier)
  })
_sym_db.RegisterMessage(HealthCheckSpecifier)


DESCRIPTOR._options = None

_HEALTHDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='HealthDiscoveryService',
  full_name='envoy.service.discovery.v2.HealthDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1466,
  serialized_end=1828,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamHealthCheck',
    full_name='envoy.service.discovery.v2.HealthDiscoveryService.StreamHealthCheck',
    index=0,
    containing_service=None,
    input_type=_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE,
    output_type=_HEALTHCHECKSPECIFIER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchHealthCheck',
    full_name='envoy.service.discovery.v2.HealthDiscoveryService.FetchHealthCheck',
    index=1,
    containing_service=None,
    input_type=_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE,
    output_type=_HEALTHCHECKSPECIFIER,
    serialized_options=b'\202\323\344\223\002\034\"\032/v2/discovery:health_check\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HEALTHDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['HealthDiscoveryService'] = _HEALTHDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v4alpha/string.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v4alpha import regex_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/matcher/v4alpha/string.proto',
  package='envoy.type.matcher.v4alpha',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.type.matcher.v4alphaB\013StringProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'envoy/type/matcher/v4alpha/string.proto\x12\x1a\x65nvoy.type.matcher.v4alpha\x1a&envoy/type/matcher/v4alpha/regex.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xa1\x02\n\rStringMatcher\x12\x0f\n\x05\x65xact\x18\x01 \x01(\tH\x00\x12\x19\n\x06prefix\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x19\n\x06suffix\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12H\n\nsafe_regex\x18\x05 \x01(\x0b\x32(.envoy.type.matcher.v4alpha.RegexMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x1b\n\x08\x63ontains\x18\x07 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x13\n\x0bignore_case\x18\x06 \x01(\x08:*\x9a\xc5\x88\x1e%\n#envoy.type.matcher.v3.StringMatcherB\x14\n\rmatch_pattern\x12\x03\xf8\x42\x01J\x04\x08\x04\x10\x05R\x05regex\"\x8a\x01\n\x11ListStringMatcher\x12\x45\n\x08patterns\x18\x01 \x03(\x0b\x32).envoy.type.matcher.v4alpha.StringMatcherB\x08\xfa\x42\x05\x92\x01\x02\x08\x01:.\x9a\xc5\x88\x1e)\n\'envoy.type.matcher.v3.ListStringMatcherBA\n(io.envoyproxy.envoy.type.matcher.v4alphaB\x0bStringProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STRINGMATCHER = _descriptor.Descriptor(
  name='StringMatcher',
  full_name='envoy.type.matcher.v4alpha.StringMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exact', full_name='envoy.type.matcher.v4alpha.StringMatcher.exact', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='envoy.type.matcher.v4alpha.StringMatcher.prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='suffix', full_name='envoy.type.matcher.v4alpha.StringMatcher.suffix', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safe_regex', full_name='envoy.type.matcher.v4alpha.StringMatcher.safe_regex', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contains', full_name='envoy.type.matcher.v4alpha.StringMatcher.contains', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_case', full_name='envoy.type.matcher.v4alpha.StringMatcher.ignore_case', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.type.matcher.v3.StringMatcher',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='match_pattern', full_name='envoy.type.matcher.v4alpha.StringMatcher.match_pattern',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=203,
  serialized_end=492,
)


_LISTSTRINGMATCHER = _descriptor.Descriptor(
  name='ListStringMatcher',
  full_name='envoy.type.matcher.v4alpha.ListStringMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='patterns', full_name='envoy.type.matcher.v4alpha.ListStringMatcher.patterns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036)\n\'envoy.type.matcher.v3.ListStringMatcher',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=495,
  serialized_end=633,
)

_STRINGMATCHER.fields_by_name['safe_regex'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2._REGEXMATCHER
_STRINGMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _STRINGMATCHER.fields_by_name['exact'])
_STRINGMATCHER.fields_by_name['exact'].containing_oneof = _STRINGMATCHER.oneofs_by_name['match_pattern']
_STRINGMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _STRINGMATCHER.fields_by_name['prefix'])
_STRINGMATCHER.fields_by_name['prefix'].containing_oneof = _STRINGMATCHER.oneofs_by_name['match_pattern']
_STRINGMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _STRINGMATCHER.fields_by_name['suffix'])
_STRINGMATCHER.fields_by_name['suffix'].containing_oneof = _STRINGMATCHER.oneofs_by_name['match_pattern']
_STRINGMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _STRINGMATCHER.fields_by_name['safe_regex'])
_STRINGMATCHER.fields_by_name['safe_regex'].containing_oneof = _STRINGMATCHER.oneofs_by_name['match_pattern']
_STRINGMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _STRINGMATCHER.fields_by_name['contains'])
_STRINGMATCHER.fields_by_name['contains'].containing_oneof = _STRINGMATCHER.oneofs_by_name['match_pattern']
_LISTSTRINGMATCHER.fields_by_name['patterns'].message_type = _STRINGMATCHER
DESCRIPTOR.message_types_by_name['StringMatcher'] = _STRINGMATCHER
DESCRIPTOR.message_types_by_name['ListStringMatcher'] = _LISTSTRINGMATCHER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StringMatcher = _reflection.GeneratedProtocolMessageType('StringMatcher', (_message.Message,), {
  'DESCRIPTOR' : _STRINGMATCHER,
  '__module__' : 'envoy.type.matcher.v4alpha.string_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.v4alpha.StringMatcher)
  })
_sym_db.RegisterMessage(StringMatcher)

ListStringMatcher = _reflection.GeneratedProtocolMessageType('ListStringMatcher', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTRINGMATCHER,
  '__module__' : 'envoy.type.matcher.v4alpha.string_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.v4alpha.ListStringMatcher)
  })
_sym_db.RegisterMessage(ListStringMatcher)


DESCRIPTOR._options = None
_STRINGMATCHER.oneofs_by_name['match_pattern']._options = None
_STRINGMATCHER.fields_by_name['prefix']._options = None
_STRINGMATCHER.fields_by_name['suffix']._options = None
_STRINGMATCHER.fields_by_name['safe_regex']._options = None
_STRINGMATCHER.fields_by_name['contains']._options = None
_STRINGMATCHER._options = None
_LISTSTRINGMATCHER.fields_by_name['patterns']._options = None
_LISTSTRINGMATCHER._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/route/v3/srds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/route/v3/srds.proto',
  package='envoy.service.route.v3',
  syntax='proto3',
  serialized_options=b'\n$io.envoyproxy.envoy.service.route.v3B\tSrdsProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!envoy/service/route/v3/srds.proto\x12\x16\x65nvoy.service.route.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"*\n\tSrdsDummy:\x1d\x9a\xc5\x88\x1e\x18\n\x16\x65nvoy.api.v2.SrdsDummy2\xf3\x03\n\x1cScopedRoutesDiscoveryService\x12w\n\x12StreamScopedRoutes\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x80\x01\n\x11\x44\x65ltaScopedRoutes\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12\x9e\x01\n\x11\x46\x65tchScopedRoutes\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\",\x82\xd3\xe4\x93\x02\x1d\"\x1b/v3/discovery:scoped-routes\x82\xd3\xe4\x93\x02\x03:\x01*\x1a\x36\x8a\xa4\x96\xf3\x07\x30\n.envoy.config.route.v3.ScopedRouteConfigurationB>\n$io.envoyproxy.envoy.service.route.v3B\tSrdsProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_SRDSDUMMY = _descriptor.Descriptor(
  name='SrdsDummy',
  full_name='envoy.service.route.v3.SrdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\030\n\026envoy.api.v2.SrdsDummy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=277,
)

DESCRIPTOR.message_types_by_name['SrdsDummy'] = _SRDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SrdsDummy = _reflection.GeneratedProtocolMessageType('SrdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _SRDSDUMMY,
  '__module__' : 'envoy.service.route.v3.srds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.route.v3.SrdsDummy)
  })
_sym_db.RegisterMessage(SrdsDummy)


DESCRIPTOR._options = None
_SRDSDUMMY._options = None

_SCOPEDROUTESDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='ScopedRoutesDiscoveryService',
  full_name='envoy.service.route.v3.ScopedRoutesDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\0070\n.envoy.config.route.v3.ScopedRouteConfiguration',
  create_key=_descriptor._internal_create_key,
  serialized_start=280,
  serialized_end=779,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamScopedRoutes',
    full_name='envoy.service.route.v3.ScopedRoutesDiscoveryService.StreamScopedRoutes',
    index=0,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeltaScopedRoutes',
    full_name='envoy.service.route.v3.ScopedRoutesDiscoveryService.DeltaScopedRoutes',
    index=1,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchScopedRoutes',
    full_name='envoy.service.route.v3.ScopedRoutesDiscoveryService.FetchScopedRoutes',
    index=2,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\"\033/v3/discovery:scoped-routes\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SCOPEDROUTESDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['ScopedRoutesDiscoveryService'] = _SCOPEDROUTESDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/fault/v3/fault.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.extensions.filters.common.fault.v3 import fault_pb2 as envoy_dot_extensions_dot_filters_dot_common_dot_fault_dot_v3_dot_fault__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/fault/v3/fault.proto',
  package='envoy.extensions.filters.http.fault.v3',
  syntax='proto3',
  serialized_options=b'\n4io.envoyproxy.envoy.extensions.filters.http.fault.v3B\nFaultProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2envoy/extensions/filters/http/fault/v3/fault.proto\x12&envoy.extensions.filters.http.fault.v3\x1a,envoy/config/route/v3/route_components.proto\x1a\x34\x65nvoy/extensions/filters/common/fault/v3/fault.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf3\x02\n\nFaultAbort\x12\"\n\x0bhttp_status\x18\x02 \x01(\rB\x0b\xfa\x42\x08*\x06\x10\xd8\x04(\xc8\x01H\x00\x12\x15\n\x0bgrpc_status\x18\x05 \x01(\rH\x00\x12V\n\x0cheader_abort\x18\x04 \x01(\x0b\x32>.envoy.extensions.filters.http.fault.v3.FaultAbort.HeaderAbortH\x00\x12\x34\n\npercentage\x18\x03 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x1aN\n\x0bHeaderAbort:?\x9a\xc5\x88\x1e:\n8envoy.config.filter.http.fault.v2.FaultAbort.HeaderAbort:3\x9a\xc5\x88\x1e.\n,envoy.config.filter.http.fault.v2.FaultAbortB\x11\n\nerror_type\x12\x03\xf8\x42\x01J\x04\x08\x01\x10\x02\"\xb6\x05\n\tHTTPFault\x12\x43\n\x05\x64\x65lay\x18\x01 \x01(\x0b\x32\x34.envoy.extensions.filters.common.fault.v3.FaultDelay\x12\x41\n\x05\x61\x62ort\x18\x02 \x01(\x0b\x32\x32.envoy.extensions.filters.http.fault.v3.FaultAbort\x12\x18\n\x10upstream_cluster\x18\x03 \x01(\t\x12\x35\n\x07headers\x18\x04 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher\x12\x18\n\x10\x64ownstream_nodes\x18\x05 \x03(\t\x12\x37\n\x11max_active_faults\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12U\n\x13response_rate_limit\x18\x07 \x01(\x0b\x32\x38.envoy.extensions.filters.common.fault.v3.FaultRateLimit\x12\x1d\n\x15\x64\x65lay_percent_runtime\x18\x08 \x01(\t\x12\x1d\n\x15\x61\x62ort_percent_runtime\x18\t \x01(\t\x12\x1e\n\x16\x64\x65lay_duration_runtime\x18\n \x01(\t\x12!\n\x19\x61\x62ort_http_status_runtime\x18\x0b \x01(\t\x12!\n\x19max_active_faults_runtime\x18\x0c \x01(\t\x12+\n#response_rate_limit_percent_runtime\x18\r \x01(\t\x12!\n\x19\x61\x62ort_grpc_status_runtime\x18\x0e \x01(\t:2\x9a\xc5\x88\x1e-\n+envoy.config.filter.http.fault.v2.HTTPFaultBL\n4io.envoyproxy.envoy.extensions.filters.http.fault.v3B\nFaultProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2.DESCRIPTOR,envoy_dot_extensions_dot_filters_dot_common_dot_fault_dot_v3_dot_fault__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_FAULTABORT_HEADERABORT = _descriptor.Descriptor(
  name='HeaderAbort',
  full_name='envoy.extensions.filters.http.fault.v3.FaultAbort.HeaderAbort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036:\n8envoy.config.filter.http.fault.v2.FaultAbort.HeaderAbort',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=562,
  serialized_end=640,
)

_FAULTABORT = _descriptor.Descriptor(
  name='FaultAbort',
  full_name='envoy.extensions.filters.http.fault.v3.FaultAbort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_status', full_name='envoy.extensions.filters.http.fault.v3.FaultAbort.http_status', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010*\006\020\330\004(\310\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_status', full_name='envoy.extensions.filters.http.fault.v3.FaultAbort.grpc_status', index=1,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_abort', full_name='envoy.extensions.filters.http.fault.v3.FaultAbort.header_abort', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='envoy.extensions.filters.http.fault.v3.FaultAbort.percentage', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FAULTABORT_HEADERABORT, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.config.filter.http.fault.v2.FaultAbort',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='error_type', full_name='envoy.extensions.filters.http.fault.v3.FaultAbort.error_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=347,
  serialized_end=718,
)


_HTTPFAULT = _descriptor.Descriptor(
  name='HTTPFault',
  full_name='envoy.extensions.filters.http.fault.v3.HTTPFault',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delay', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.delay', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='abort', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.abort', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_cluster', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.upstream_cluster', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.headers', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downstream_nodes', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.downstream_nodes', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_active_faults', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.max_active_faults', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_rate_limit', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.response_rate_limit', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay_percent_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.delay_percent_runtime', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='abort_percent_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.abort_percent_runtime', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay_duration_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.delay_duration_runtime', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='abort_http_status_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.abort_http_status_runtime', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_active_faults_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.max_active_faults_runtime', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_rate_limit_percent_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.response_rate_limit_percent_runtime', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='abort_grpc_status_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.abort_grpc_status_runtime', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.config.filter.http.fault.v2.HTTPFault',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=721,
  serialized_end=1415,
)

_FAULTABORT_HEADERABORT.containing_type = _FAULTABORT
_FAULTABORT.fields_by_name['header_abort'].message_type = _FAULTABORT_HEADERABORT
_FAULTABORT.fields_by_name['percentage'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._FRACTIONALPERCENT
_FAULTABORT.oneofs_by_name['error_type'].fields.append(
  _FAULTABORT.fields_by_name['http_status'])
_FAULTABORT.fields_by_name['http_status'].containing_oneof = _FAULTABORT.oneofs_by_name['error_type']
_FAULTABORT.oneofs_by_name['error_type'].fields.append(
  _FAULTABORT.fields_by_name['grpc_status'])
_FAULTABORT.fields_by_name['grpc_status'].containing_oneof = _FAULTABORT.oneofs_by_name['error_type']
_FAULTABORT.oneofs_by_name['error_type'].fields.append(
  _FAULTABORT.fields_by_name['header_abort'])
_FAULTABORT.fields_by_name['header_abort'].containing_oneof = _FAULTABORT.oneofs_by_name['error_type']
_HTTPFAULT.fields_by_name['delay'].message_type = envoy_dot_extensions_dot_filters_dot_common_dot_fault_dot_v3_dot_fault__pb2._FAULTDELAY
_HTTPFAULT.fields_by_name['abort'].message_type = _FAULTABORT
_HTTPFAULT.fields_by_name['headers'].message_type = envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2._HEADERMATCHER
_HTTPFAULT.fields_by_name['max_active_faults'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTPFAULT.fields_by_name['response_rate_limit'].message_type = envoy_dot_extensions_dot_filters_dot_common_dot_fault_dot_v3_dot_fault__pb2._FAULTRATELIMIT
DESCRIPTOR.message_types_by_name['FaultAbort'] = _FAULTABORT
DESCRIPTOR.message_types_by_name['HTTPFault'] = _HTTPFAULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaultAbort = _reflection.GeneratedProtocolMessageType('FaultAbort', (_message.Message,), {

  'HeaderAbort' : _reflection.GeneratedProtocolMessageType('HeaderAbort', (_message.Message,), {
    'DESCRIPTOR' : _FAULTABORT_HEADERABORT,
    '__module__' : 'envoy.extensions.filters.http.fault.v3.fault_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.fault.v3.FaultAbort.HeaderAbort)
    })
  ,
  'DESCRIPTOR' : _FAULTABORT,
  '__module__' : 'envoy.extensions.filters.http.fault.v3.fault_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.fault.v3.FaultAbort)
  })
_sym_db.RegisterMessage(FaultAbort)
_sym_db.RegisterMessage(FaultAbort.HeaderAbort)

HTTPFault = _reflection.GeneratedProtocolMessageType('HTTPFault', (_message.Message,), {
  'DESCRIPTOR' : _HTTPFAULT,
  '__module__' : 'envoy.extensions.filters.http.fault.v3.fault_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.fault.v3.HTTPFault)
  })
_sym_db.RegisterMessage(HTTPFault)


DESCRIPTOR._options = None
_FAULTABORT_HEADERABORT._options = None
_FAULTABORT.oneofs_by_name['error_type']._options = None
_FAULTABORT.fields_by_name['http_status']._options = None
_FAULTABORT._options = None
_HTTPFAULT._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/listeners.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v2alpha/listeners.proto',
  package='envoy.admin.v2alpha',
  syntax='proto3',
  serialized_options=b'\n!io.envoyproxy.envoy.admin.v2alphaB\016ListenersProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/admin/v2alpha/listeners.proto\x12\x13\x65nvoy.admin.v2alpha\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1dudpa/annotations/status.proto\"K\n\tListeners\x12>\n\x11listener_statuses\x18\x01 \x03(\x0b\x32#.envoy.admin.v2alpha.ListenerStatus\"Q\n\x0eListenerStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x31\n\rlocal_address\x18\x02 \x01(\x0b\x32\x1a.envoy.api.v2.core.AddressB=\n!io.envoyproxy.envoy.admin.v2alphaB\x0eListenersProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_address__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_LISTENERS = _descriptor.Descriptor(
  name='Listeners',
  full_name='envoy.admin.v2alpha.Listeners',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='listener_statuses', full_name='envoy.admin.v2alpha.Listeners.listener_statuses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=199,
)


_LISTENERSTATUS = _descriptor.Descriptor(
  name='ListenerStatus',
  full_name='envoy.admin.v2alpha.ListenerStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.ListenerStatus.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_address', full_name='envoy.admin.v2alpha.ListenerStatus.local_address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=282,
)

_LISTENERS.fields_by_name['listener_statuses'].message_type = _LISTENERSTATUS
_LISTENERSTATUS.fields_by_name['local_address'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._ADDRESS
DESCRIPTOR.message_types_by_name['Listeners'] = _LISTENERS
DESCRIPTOR.message_types_by_name['ListenerStatus'] = _LISTENERSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Listeners = _reflection.GeneratedProtocolMessageType('Listeners', (_message.Message,), {
  'DESCRIPTOR' : _LISTENERS,
  '__module__' : 'envoy.admin.v2alpha.listeners_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.Listeners)
  })
_sym_db.RegisterMessage(Listeners)

ListenerStatus = _reflection.GeneratedProtocolMessageType('ListenerStatus', (_message.Message,), {
  'DESCRIPTOR' : _LISTENERSTATUS,
  '__module__' : 'envoy.admin.v2alpha.listeners_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ListenerStatus)
  })
_sym_db.RegisterMessage(ListenerStatus)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/csrf/v2/csrf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/csrf/v2/csrf.proto',
  package='envoy.config.filter.http.csrf.v2',
  syntax='proto3',
  serialized_options=b'\n.io.envoyproxy.envoy.config.filter.http.csrf.v2B\tCsrfProtoP\001\362\230\376\217\005\'\022%envoy.extensions.filters.http.csrf.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+envoy/config/filter/http/csrf/v2/csrf.proto\x12 envoy.config.filter.http.csrf.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdf\x01\n\nCsrfPolicy\x12M\n\x0e\x66ilter_enabled\x18\x01 \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercentB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x43\n\x0eshadow_enabled\x18\x02 \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercent\x12=\n\x12\x61\x64\x64itional_origins\x18\x03 \x03(\x0b\x32!.envoy.type.matcher.StringMatcherBr\n.io.envoyproxy.envoy.config.filter.http.csrf.v2B\tCsrfProtoP\x01\xf2\x98\xfe\x8f\x05\'\x12%envoy.extensions.filters.http.csrf.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_string__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CSRFPOLICY = _descriptor.Descriptor(
  name='CsrfPolicy',
  full_name='envoy.config.filter.http.csrf.v2.CsrfPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter_enabled', full_name='envoy.config.filter.http.csrf.v2.CsrfPolicy.filter_enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shadow_enabled', full_name='envoy.config.filter.http.csrf.v2.CsrfPolicy.shadow_enabled', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_origins', full_name='envoy.config.filter.http.csrf.v2.CsrfPolicy.additional_origins', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=456,
)

_CSRFPOLICY.fields_by_name['filter_enabled'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_CSRFPOLICY.fields_by_name['shadow_enabled'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_CSRFPOLICY.fields_by_name['additional_origins'].message_type = envoy_dot_type_dot_matcher_dot_string__pb2._STRINGMATCHER
DESCRIPTOR.message_types_by_name['CsrfPolicy'] = _CSRFPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CsrfPolicy = _reflection.GeneratedProtocolMessageType('CsrfPolicy', (_message.Message,), {
  'DESCRIPTOR' : _CSRFPOLICY,
  '__module__' : 'envoy.config.filter.http.csrf.v2.csrf_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.csrf.v2.CsrfPolicy)
  })
_sym_db.RegisterMessage(CsrfPolicy)


DESCRIPTOR._options = None
_CSRFPOLICY.fields_by_name['filter_enabled']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/aws_lambda/v2alpha/aws_lambda.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/aws_lambda/v2alpha/aws_lambda.proto',
  package='envoy.config.filter.http.aws_lambda.v2alpha',
  syntax='proto3',
  serialized_options=b'\n9io.envoyproxy.envoy.config.filter.http.aws_lambda.v2alphaB\016AwsLambdaProtoP\001\362\230\376\217\005-\022+envoy.extensions.filters.http.aws_lambda.v3\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<envoy/config/filter/http/aws_lambda/v2alpha/aws_lambda.proto\x12+envoy.config.filter.http.aws_lambda.v2alpha\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xd7\x01\n\x06\x43onfig\x12\x14\n\x03\x61rn\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1b\n\x13payload_passthrough\x18\x02 \x01(\x08\x12\x65\n\x0finvocation_mode\x18\x03 \x01(\x0e\x32\x42.envoy.config.filter.http.aws_lambda.v2alpha.Config.InvocationModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"3\n\x0eInvocationMode\x12\x0f\n\x0bSYNCHRONOUS\x10\x00\x12\x10\n\x0c\x41SYNCHRONOUS\x10\x01\"\\\n\x0ePerRouteConfig\x12J\n\rinvoke_config\x18\x01 \x01(\x0b\x32\x33.envoy.config.filter.http.aws_lambda.v2alpha.ConfigB\x90\x01\n9io.envoyproxy.envoy.config.filter.http.aws_lambda.v2alphaB\x0e\x41wsLambdaProtoP\x01\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.filters.http.aws_lambda.v3\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_CONFIG_INVOCATIONMODE = _descriptor.EnumDescriptor(
  name='InvocationMode',
  full_name='envoy.config.filter.http.aws_lambda.v2alpha.Config.InvocationMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SYNCHRONOUS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASYNCHRONOUS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=362,
  serialized_end=413,
)
_sym_db.RegisterEnumDescriptor(_CONFIG_INVOCATIONMODE)


_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='envoy.config.filter.http.aws_lambda.v2alpha.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='arn', full_name='envoy.config.filter.http.aws_lambda.v2alpha.Config.arn', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_passthrough', full_name='envoy.config.filter.http.aws_lambda.v2alpha.Config.payload_passthrough', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invocation_mode', full_name='envoy.config.filter.http.aws_lambda.v2alpha.Config.invocation_mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONFIG_INVOCATIONMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=198,
  serialized_end=413,
)


_PERROUTECONFIG = _descriptor.Descriptor(
  name='PerRouteConfig',
  full_name='envoy.config.filter.http.aws_lambda.v2alpha.PerRouteConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invoke_config', full_name='envoy.config.filter.http.aws_lambda.v2alpha.PerRouteConfig.invoke_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=507,
)

_CONFIG.fields_by_name['invocation_mode'].enum_type = _CONFIG_INVOCATIONMODE
_CONFIG_INVOCATIONMODE.containing_type = _CONFIG
_PERROUTECONFIG.fields_by_name['invoke_config'].message_type = _CONFIG
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.message_types_by_name['PerRouteConfig'] = _PERROUTECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'envoy.config.filter.http.aws_lambda.v2alpha.aws_lambda_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.aws_lambda.v2alpha.Config)
  })
_sym_db.RegisterMessage(Config)

PerRouteConfig = _reflection.GeneratedProtocolMessageType('PerRouteConfig', (_message.Message,), {
  'DESCRIPTOR' : _PERROUTECONFIG,
  '__module__' : 'envoy.config.filter.http.aws_lambda.v2alpha.aws_lambda_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.aws_lambda.v2alpha.PerRouteConfig)
  })
_sym_db.RegisterMessage(PerRouteConfig)


DESCRIPTOR._options = None
_CONFIG.fields_by_name['arn']._options = None
_CONFIG.fields_by_name['invocation_mode']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/trace/v2/trace_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from opencensus.proto.trace.v1 import trace_pb2 as opencensus_dot_proto_dot_trace_dot_v1_dot_trace__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/trace/v2/trace_service.proto',
  package='envoy.service.trace.v2',
  syntax='proto3',
  serialized_options=b'\n$io.envoyproxy.envoy.service.trace.v2B\021TraceServiceProtoP\001\210\001\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*envoy/service/trace/v2/trace_service.proto\x12\x16\x65nvoy.service.trace.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%opencensus/proto/trace/v1/trace.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x16\n\x14StreamTracesResponse\"\xd0\x01\n\x13StreamTracesMessage\x12J\n\nidentifier\x18\x01 \x01(\x0b\x32\x36.envoy.service.trace.v2.StreamTracesMessage.Identifier\x12.\n\x05spans\x18\x02 \x03(\x0b\x32\x1f.opencensus.proto.trace.v1.Span\x1a=\n\nIdentifier\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x32}\n\x0cTraceService\x12m\n\x0cStreamTraces\x12+.envoy.service.trace.v2.StreamTracesMessage\x1a,.envoy.service.trace.v2.StreamTracesResponse\"\x00(\x01\x42\x46\n$io.envoyproxy.envoy.service.trace.v2B\x11TraceServiceProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,opencensus_dot_proto_dot_trace_dot_v1_dot_trace__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STREAMTRACESRESPONSE = _descriptor.Descriptor(
  name='StreamTracesResponse',
  full_name='envoy.service.trace.v2.StreamTracesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=195,
  serialized_end=217,
)


_STREAMTRACESMESSAGE_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='envoy.service.trace.v2.StreamTracesMessage.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.trace.v2.StreamTracesMessage.Identifier.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=428,
)

_STREAMTRACESMESSAGE = _descriptor.Descriptor(
  name='StreamTracesMessage',
  full_name='envoy.service.trace.v2.StreamTracesMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='envoy.service.trace.v2.StreamTracesMessage.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spans', full_name='envoy.service.trace.v2.StreamTracesMessage.spans', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMTRACESMESSAGE_IDENTIFIER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=428,
)

_STREAMTRACESMESSAGE_IDENTIFIER.fields_by_name['node'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._NODE
_STREAMTRACESMESSAGE_IDENTIFIER.containing_type = _STREAMTRACESMESSAGE
_STREAMTRACESMESSAGE.fields_by_name['identifier'].message_type = _STREAMTRACESMESSAGE_IDENTIFIER
_STREAMTRACESMESSAGE.fields_by_name['spans'].message_type = opencensus_dot_proto_dot_trace_dot_v1_dot_trace__pb2._SPAN
DESCRIPTOR.message_types_by_name['StreamTracesResponse'] = _STREAMTRACESRESPONSE
DESCRIPTOR.message_types_by_name['StreamTracesMessage'] = _STREAMTRACESMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamTracesResponse = _reflection.GeneratedProtocolMessageType('StreamTracesResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTRACESRESPONSE,
  '__module__' : 'envoy.service.trace.v2.trace_service_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.trace.v2.StreamTracesResponse)
  })
_sym_db.RegisterMessage(StreamTracesResponse)

StreamTracesMessage = _reflection.GeneratedProtocolMessageType('StreamTracesMessage', (_message.Message,), {

  'Identifier' : _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
    'DESCRIPTOR' : _STREAMTRACESMESSAGE_IDENTIFIER,
    '__module__' : 'envoy.service.trace.v2.trace_service_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.trace.v2.StreamTracesMessage.Identifier)
    })
  ,
  'DESCRIPTOR' : _STREAMTRACESMESSAGE,
  '__module__' : 'envoy.service.trace.v2.trace_service_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.trace.v2.StreamTracesMessage)
  })
_sym_db.RegisterMessage(StreamTracesMessage)
_sym_db.RegisterMessage(StreamTracesMessage.Identifier)


DESCRIPTOR._options = None
_STREAMTRACESMESSAGE_IDENTIFIER.fields_by_name['node']._options = None

_TRACESERVICE = _descriptor.ServiceDescriptor(
  name='TraceService',
  full_name='envoy.service.trace.v2.TraceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=430,
  serialized_end=555,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamTraces',
    full_name='envoy.service.trace.v2.TraceService.StreamTraces',
    index=0,
    containing_service=None,
    input_type=_STREAMTRACESMESSAGE,
    output_type=_STREAMTRACESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRACESERVICE)

DESCRIPTOR.services_by_name['TraceService'] = _TRACESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/tap/v2alpha/tap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.data.tap.v2alpha import wrapper_pb2 as envoy_dot_data_dot_tap_dot_v2alpha_dot_wrapper__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/tap/v2alpha/tap.proto',
  package='envoy.service.tap.v2alpha',
  syntax='proto3',
  serialized_options=b'\n\'io.envoyproxy.envoy.service.tap.v2alphaB\010TapProtoP\001\210\001\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/service/tap/v2alpha/tap.proto\x12\x19\x65nvoy.service.tap.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/data/tap/v2alpha/wrapper.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf6\x01\n\x11StreamTapsRequest\x12K\n\nidentifier\x18\x01 \x01(\x0b\x32\x37.envoy.service.tap.v2alpha.StreamTapsRequest.Identifier\x12\x10\n\x08trace_id\x18\x02 \x01(\x04\x12\x33\n\x05trace\x18\x03 \x01(\x0b\x32$.envoy.data.tap.v2alpha.TraceWrapper\x1aM\n\nIdentifier\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0e\n\x06tap_id\x18\x02 \x01(\t\"\x14\n\x12StreamTapsResponse2\x7f\n\x0eTapSinkService\x12m\n\nStreamTaps\x12,.envoy.service.tap.v2alpha.StreamTapsRequest\x1a-.envoy.service.tap.v2alpha.StreamTapsResponse\"\x00(\x01\x42@\n\'io.envoyproxy.envoy.service.tap.v2alphaB\x08TapProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_data_dot_tap_dot_v2alpha_dot_wrapper__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STREAMTAPSREQUEST_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='envoy.service.tap.v2alpha.StreamTapsRequest.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.tap.v2alpha.StreamTapsRequest.Identifier.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tap_id', full_name='envoy.service.tap.v2alpha.StreamTapsRequest.Identifier.tap_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=437,
)

_STREAMTAPSREQUEST = _descriptor.Descriptor(
  name='StreamTapsRequest',
  full_name='envoy.service.tap.v2alpha.StreamTapsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='envoy.service.tap.v2alpha.StreamTapsRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='envoy.service.tap.v2alpha.StreamTapsRequest.trace_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trace', full_name='envoy.service.tap.v2alpha.StreamTapsRequest.trace', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMTAPSREQUEST_IDENTIFIER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=437,
)


_STREAMTAPSRESPONSE = _descriptor.Descriptor(
  name='StreamTapsResponse',
  full_name='envoy.service.tap.v2alpha.StreamTapsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=439,
  serialized_end=459,
)

_STREAMTAPSREQUEST_IDENTIFIER.fields_by_name['node'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._NODE
_STREAMTAPSREQUEST_IDENTIFIER.containing_type = _STREAMTAPSREQUEST
_STREAMTAPSREQUEST.fields_by_name['identifier'].message_type = _STREAMTAPSREQUEST_IDENTIFIER
_STREAMTAPSREQUEST.fields_by_name['trace'].message_type = envoy_dot_data_dot_tap_dot_v2alpha_dot_wrapper__pb2._TRACEWRAPPER
DESCRIPTOR.message_types_by_name['StreamTapsRequest'] = _STREAMTAPSREQUEST
DESCRIPTOR.message_types_by_name['StreamTapsResponse'] = _STREAMTAPSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamTapsRequest = _reflection.GeneratedProtocolMessageType('StreamTapsRequest', (_message.Message,), {

  'Identifier' : _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
    'DESCRIPTOR' : _STREAMTAPSREQUEST_IDENTIFIER,
    '__module__' : 'envoy.service.tap.v2alpha.tap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.tap.v2alpha.StreamTapsRequest.Identifier)
    })
  ,
  'DESCRIPTOR' : _STREAMTAPSREQUEST,
  '__module__' : 'envoy.service.tap.v2alpha.tap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.tap.v2alpha.StreamTapsRequest)
  })
_sym_db.RegisterMessage(StreamTapsRequest)
_sym_db.RegisterMessage(StreamTapsRequest.Identifier)

StreamTapsResponse = _reflection.GeneratedProtocolMessageType('StreamTapsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTAPSRESPONSE,
  '__module__' : 'envoy.service.tap.v2alpha.tap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.tap.v2alpha.StreamTapsResponse)
  })
_sym_db.RegisterMessage(StreamTapsResponse)


DESCRIPTOR._options = None
_STREAMTAPSREQUEST_IDENTIFIER.fields_by_name['node']._options = None

_TAPSINKSERVICE = _descriptor.ServiceDescriptor(
  name='TapSinkService',
  full_name='envoy.service.tap.v2alpha.TapSinkService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=461,
  serialized_end=588,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamTaps',
    full_name='envoy.service.tap.v2alpha.TapSinkService.StreamTaps',
    index=0,
    containing_service=None,
    input_type=_STREAMTAPSREQUEST,
    output_type=_STREAMTAPSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TAPSINKSERVICE)

DESCRIPTOR.services_by_name['TapSinkService'] = _TAPSINKSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/clusters/dynamic_forward_proxy/v3/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.common.dynamic_forward_proxy.v3 import dns_cache_pb2 as envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/clusters/dynamic_forward_proxy/v3/cluster.proto',
  package='envoy.extensions.clusters.dynamic_forward_proxy.v3',
  syntax='proto3',
  serialized_options=b'\n@io.envoyproxy.envoy.extensions.clusters.dynamic_forward_proxy.v3B\014ClusterProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@envoy/extensions/clusters/dynamic_forward_proxy/v3/cluster.proto\x12\x32\x65nvoy.extensions.clusters.dynamic_forward_proxy.v3\x1a@envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe6\x01\n\rClusterConfig\x12\x64\n\x10\x64ns_cache_config\x18\x01 \x01(\x0b\x32@.envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12&\n\x1e\x61llow_insecure_cluster_options\x18\x02 \x01(\x08:G\x9a\xc5\x88\x1e\x42\n@envoy.config.cluster.dynamic_forward_proxy.v2alpha.ClusterConfigBZ\n@io.envoyproxy.envoy.extensions.clusters.dynamic_forward_proxy.v3B\x0c\x43lusterProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CLUSTERCONFIG = _descriptor.Descriptor(
  name='ClusterConfig',
  full_name='envoy.extensions.clusters.dynamic_forward_proxy.v3.ClusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_cache_config', full_name='envoy.extensions.clusters.dynamic_forward_proxy.v3.ClusterConfig.dns_cache_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_insecure_cluster_options', full_name='envoy.extensions.clusters.dynamic_forward_proxy.v3.ClusterConfig.allow_insecure_cluster_options', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036B\n@envoy.config.cluster.dynamic_forward_proxy.v2alpha.ClusterConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=508,
)

_CLUSTERCONFIG.fields_by_name['dns_cache_config'].message_type = envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2._DNSCACHECONFIG
DESCRIPTOR.message_types_by_name['ClusterConfig'] = _CLUSTERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClusterConfig = _reflection.GeneratedProtocolMessageType('ClusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERCONFIG,
  '__module__' : 'envoy.extensions.clusters.dynamic_forward_proxy.v3.cluster_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.clusters.dynamic_forward_proxy.v3.ClusterConfig)
  })
_sym_db.RegisterMessage(ClusterConfig)


DESCRIPTOR._options = None
_CLUSTERCONFIG.fields_by_name['dns_cache_config']._options = None
_CLUSTERCONFIG._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v3/wrapper.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.data.tap.v3 import http_pb2 as envoy_dot_data_dot_tap_dot_v3_dot_http__pb2
from envoy.data.tap.v3 import transport_pb2 as envoy_dot_data_dot_tap_dot_v3_dot_transport__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/data/tap/v3/wrapper.proto',
  package='envoy.data.tap.v3',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.data.tap.v3B\014WrapperProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x65nvoy/data/tap/v3/wrapper.proto\x12\x11\x65nvoy.data.tap.v3\x1a\x1c\x65nvoy/data/tap/v3/http.proto\x1a!envoy/data/tap/v3/transport.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x82\x03\n\x0cTraceWrapper\x12\x43\n\x13http_buffered_trace\x18\x01 \x01(\x0b\x32$.envoy.data.tap.v3.HttpBufferedTraceH\x00\x12R\n\x1bhttp_streamed_trace_segment\x18\x02 \x01(\x0b\x32+.envoy.data.tap.v3.HttpStreamedTraceSegmentH\x00\x12G\n\x15socket_buffered_trace\x18\x03 \x01(\x0b\x32&.envoy.data.tap.v3.SocketBufferedTraceH\x00\x12V\n\x1dsocket_streamed_trace_segment\x18\x04 \x01(\x0b\x32-.envoy.data.tap.v3.SocketStreamedTraceSegmentH\x00:*\x9a\xc5\x88\x1e%\n#envoy.data.tap.v2alpha.TraceWrapperB\x0c\n\x05trace\x12\x03\xf8\x42\x01\x42\x39\n\x1fio.envoyproxy.envoy.data.tap.v3B\x0cWrapperProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_data_dot_tap_dot_v3_dot_http__pb2.DESCRIPTOR,envoy_dot_data_dot_tap_dot_v3_dot_transport__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_TRACEWRAPPER = _descriptor.Descriptor(
  name='TraceWrapper',
  full_name='envoy.data.tap.v3.TraceWrapper',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_buffered_trace', full_name='envoy.data.tap.v3.TraceWrapper.http_buffered_trace', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_streamed_trace_segment', full_name='envoy.data.tap.v3.TraceWrapper.http_streamed_trace_segment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='socket_buffered_trace', full_name='envoy.data.tap.v3.TraceWrapper.socket_buffered_trace', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='socket_streamed_trace_segment', full_name='envoy.data.tap.v3.TraceWrapper.socket_streamed_trace_segment', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.data.tap.v2alpha.TraceWrapper',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='trace', full_name='envoy.data.tap.v3.TraceWrapper.trace',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=211,
  serialized_end=597,
)

_TRACEWRAPPER.fields_by_name['http_buffered_trace'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_http__pb2._HTTPBUFFEREDTRACE
_TRACEWRAPPER.fields_by_name['http_streamed_trace_segment'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_http__pb2._HTTPSTREAMEDTRACESEGMENT
_TRACEWRAPPER.fields_by_name['socket_buffered_trace'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_transport__pb2._SOCKETBUFFEREDTRACE
_TRACEWRAPPER.fields_by_name['socket_streamed_trace_segment'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_transport__pb2._SOCKETSTREAMEDTRACESEGMENT
_TRACEWRAPPER.oneofs_by_name['trace'].fields.append(
  _TRACEWRAPPER.fields_by_name['http_buffered_trace'])
_TRACEWRAPPER.fields_by_name['http_buffered_trace'].containing_oneof = _TRACEWRAPPER.oneofs_by_name['trace']
_TRACEWRAPPER.oneofs_by_name['trace'].fields.append(
  _TRACEWRAPPER.fields_by_name['http_streamed_trace_segment'])
_TRACEWRAPPER.fields_by_name['http_streamed_trace_segment'].containing_oneof = _TRACEWRAPPER.oneofs_by_name['trace']
_TRACEWRAPPER.oneofs_by_name['trace'].fields.append(
  _TRACEWRAPPER.fields_by_name['socket_buffered_trace'])
_TRACEWRAPPER.fields_by_name['socket_buffered_trace'].containing_oneof = _TRACEWRAPPER.oneofs_by_name['trace']
_TRACEWRAPPER.oneofs_by_name['trace'].fields.append(
  _TRACEWRAPPER.fields_by_name['socket_streamed_trace_segment'])
_TRACEWRAPPER.fields_by_name['socket_streamed_trace_segment'].containing_oneof = _TRACEWRAPPER.oneofs_by_name['trace']
DESCRIPTOR.message_types_by_name['TraceWrapper'] = _TRACEWRAPPER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TraceWrapper = _reflection.GeneratedProtocolMessageType('TraceWrapper', (_message.Message,), {
  'DESCRIPTOR' : _TRACEWRAPPER,
  '__module__' : 'envoy.data.tap.v3.wrapper_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.TraceWrapper)
  })
_sym_db.RegisterMessage(TraceWrapper)


DESCRIPTOR._options = None
_TRACEWRAPPER.oneofs_by_name['trace']._options = None
_TRACEWRAPPER._options = None
# @@protoc_insertion_point(module_scope)
